/*
 * Bull SAS / OW2 Orchestra
 * Copyright (C) 2011 Bull S.A.S, and individual contributors as indicated
 * by the @authors tag.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

package org.ow2.orchestra.designer.fileNavigator;

import java.io.Serializable;

public class Item implements Serializable, Comparable<Item> {

  private static final long serialVersionUID = -7121934637732301053L;

  private String name;

  public Item() {
    super();
  }

  public String getName() {
    return this.name;
  }

  public void setName(final String name) {
    this.name = name;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;

    Item item = (Item) o;

    if (name != null ? !name.equals(item.name) : item.name != null) return false;

    return true;
  }

  @Override
  public int hashCode() {
    return name != null ? name.hashCode() : 0;
  }

  /**
   * {@inheritDoc}
   * <p/>
   * <p>Warning: according to {@link Comparable} if the given Object to compare is null this method should throw a null pointer
   * exception. By extension if one of <code>this.getName()</code> or <code>this.getName()</code> is null a a null pointer
   * exception is threw either.</p>
   */
  public int compareTo(Item o) {
    return this.getName().compareToIgnoreCase(o.getName());
  }
}
