/*
 * Copyright (C) 2011 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 */

package org.ow2.orchestra.designer.server;

import flex.messaging.messages.AsyncMessage;
import javax.servlet.ServletContext;
import org.granite.context.GraniteContext;
import org.granite.gravity.Gravity;
import org.granite.messaging.webapp.HttpGraniteContext;

/**
 * @author Loic Albertin
 */
public class NotificationsManager {

  private static NotificationsManager instance = null;

  public static final String SUBJECT_HEADER = "Subject";
  public static final String DEFAULT_SUBJECT = "Notification";
  public static final String BROADCAST_TOPIC = "*";

  private Gravity gravity = null;

  private NotificationsManager() {
    HttpGraniteContext servletGrdsContext = (HttpGraniteContext) GraniteContext.getCurrentInstance();
    if (servletGrdsContext != null) {
      ServletContext servletContext = servletGrdsContext.getServletContext();
      gravity = (Gravity) servletContext.getAttribute("org.granite.gravity.Gravity");
    }
  }

  public static synchronized NotificationsManager getInstance() {
    if (instance == null) {
      instance = new NotificationsManager();
    }
    return instance;
  }

  public void publish(final String addressee, final String subject, final String body) {
    if (gravity != null) {
      AsyncMessage message = new AsyncMessage();
      message.setDestination("gravity");
      message.setHeader(AsyncMessage.SUBTOPIC_HEADER, addressee);
      message.setHeader(NotificationsManager.SUBJECT_HEADER, subject);
      message.setBody(body);
      gravity.publishMessage(message);
    }
  }

  public void publish(final String addressee, final String body) {
    this.publish(addressee, NotificationsManager.DEFAULT_SUBJECT, body);
  }

  public void broadcast(final String body) {
    this.broadcast(NotificationsManager.DEFAULT_SUBJECT, body);
  }

  public void broadcast(final String subject, final String body) {
    this.publish(NotificationsManager.BROADCAST_TOPIC, subject, body);
  }
}
